==> MaTiSSe.py-0.1.0.tar.gz: MaTiSSe.py-0.1.0/README.md <==
 <a name="top"></a>
[![Build Status](https://travis-ci.org/szaghi/MaTiSSe.png)](https://travis-ci.org/szaghi/MaTiSSe)
[![Coverage Status](https://img.shields.io/coveralls/szaghi/MaTiSSe.svg)](https://coveralls.io/r/szaghi/MaTiSSe)
[![Latest Version](https://pypip.in/version/MaTiSSe.py/badge.svg)](https://pypi.python.org/pypi/MaTiSSe.py/)
[![Supported Python versions](https://pypip.in/py_versions/MaTiSSe.py/badge.svg)](https://pypi.python.org/pypi/MaTiSSe.py/)
[![License](https://pypip.in/license/MaTiSSe.py/badge.svg)](https://pypi.python.org/pypi/MaTiSSe.py/)
[![Development Status](https://pypip.in/status/MaTiSSe.py/badge.svg)](https://pypi.python.org/pypi/MaTiSSe.py/)
[![Ready in backlog](https://badge.waffle.io/szaghi/matisse.png?label=ready&title=Ready)](https://waffle.io/szaghi/matisse)
[![In Progress](https://badge.waffle.io/szaghi/matisse.png?label=in%20progress&title=In%20Progress)](https://waffle.io/szaghi/matisse)
[![Open bugs](https://badge.waffle.io/szaghi/matisse.png?label=bug&title=Open%20Bugs)](https://waffle.io/szaghi/matisse)

# MaTiSSe.py
### MaTiSSe.py, Markdown To Impressive Scientific Slides
MaTiSSe.py is a very simple and stupid (KISS) presentation maker based on simple `markdown` syntax producing high quality first-class html/css presentation with great support for scientific contents.

+ MaTiSSe.py is **NOT** *WYSIWYG*: it converts your sources to high quality html presentation with the same approach of LaTeX typesetting;
+ MaTiSSe.py is tailored to scientific contents (equations, figures, tables, etc...);
+ MaTiSSe.py is a Command Line Tool;
+ MaTiSSe.py is a Free, Open Source Project.

#### Documentation

MaTiSSe.py has a comprehensive [wiki](https://github.com/szaghi/MaTiSSe/wiki): read it to know how to install and use MaTiSSe.py.

#### A Taste of MaTiSSe.py
See MaTiSSe.py in action with the [getting started presentation](http://szaghi.github.io/MaTiSSe/#/slide-1) or see the following screenshots.

##### The Titlepage
![shot01](screenshots/01.png)

##### Figure environment
![shot02](screenshots/02.png)

##### LaTeX Equations support
![shot03](screenshots/03.png)

##### LaTeX-Beamer Themes support
![shot04](screenshots/04.png)

Go to [Top](#top)

## Team Members
* Stefano Zaghi, aka _szaghi_ <https://github.com/szaghi>

### Contributors
* not yet... be the first!

Go to [Top](#top)

## <a name="versions"></a>Versions History
In the following the changelog of most important releases is reported.
### v0.0.2
##### Download [ZIP](https://github.com/szaghi/MaTiSSe/archive/v0.0.2.zip) ball or [TAR](https://github.com/szaghi/MaTiSSe/archive/v0.0.2.tar.gz) one
STABLE release. Fully backward compatible. Add PyPI installation support.
### v0.0.1
##### Download [ZIP](https://github.com/szaghi/MaTiSSe/archive/v0.0.1.zip) ball or [TAR](https://github.com/szaghi/MaTiSSe/archive/v0.0.1.tar.gz) one
First, STABLE release.

Go to [Top](#top)

==> MaTiSSe.py-0.1.1.tar.gz: MaTiSSe.py-0.1.1/README.md <==
 <a name="top"></a>
# MaTiSSe.py [![Latest Version](https://pypip.in/version/MaTiSSe.py/badge.svg?style=flat)](https://pypi.python.org/pypi/MaTiSSe.py/) [![GitHub tag](https://img.shields.io/github/tag/szaghi/MaTiSSe.svg)]()

[![License](https://pypip.in/license/MaTiSSe.py/badge.svg?style=flat)](https://pypi.python.org/pypi/MaTiSSe.py/)

### MaTiSSe.py, Markdown To Impressive Scientific Slides
MaTiSSe.py is a very simple and stupid (KISS) presentation maker based on simple `markdown` syntax producing high quality first-class html/css presentation with great support for scientific contents.

+ MaTiSSe.py is **NOT** *WYSIWYG*: it converts your sources to high quality html presentation with the same approach of LaTeX typesetting;
+ MaTiSSe.py is tailored to scientific contents (equations, figures, tables, etc...);
+ MaTiSSe.py is a Command Line Tool;
+ MaTiSSe.py is a Free, Open Source Project.

### Status
[![Development Status](https://pypip.in/status/MaTiSSe.py/badge.svg?style=flat)](https://pypi.python.org/pypi/MaTiSSe.py/)
[![Build Status](https://travis-ci.org/szaghi/MaTiSSe.svg?branch=master)](https://travis-ci.org/szaghi/MaTiSSe)
[![Coverage Status](https://img.shields.io/coveralls/szaghi/MaTiSSe.svg)](https://coveralls.io/r/szaghi/MaTiSSe)
[![Code Health](https://landscape.io/github/szaghi/MaTiSSe/master/landscape.svg?style=flat)](https://landscape.io/github/szaghi/MaTiSSe/master)

#### Issues
[![GitHub issues](https://img.shields.io/github/issues/szaghi/MaTiSSe.svg)]()
[![Ready in backlog](https://badge.waffle.io/szaghi/matisse.png?label=ready&title=Ready)](https://waffle.io/szaghi/matisse)
[![In Progress](https://badge.waffle.io/szaghi/matisse.png?label=in%20progress&title=In%20Progress)](https://waffle.io/szaghi/matisse)
[![Open bugs](https://badge.waffle.io/szaghi/matisse.png?label=bug&title=Open%20Bugs)](https://waffle.io/szaghi/matisse)

#### Python support [![Supported Python versions](https://pypip.in/py_versions/MaTiSSe.py/badge.svg?style=flat)](https://pypi.python.org/pypi/MaTiSSe.py/) [![Download format](https://pypip.in/format/MaTiSSe.py/badge.svg?style=flat)](https://pypi.python.org/pypi/MaTiSSe.py/)

#### Documentation

MaTiSSe.py has a comprehensive [wiki](https://github.com/szaghi/MaTiSSe/wiki): read it to know how to install and use MaTiSSe.py.

#### A Taste of MaTiSSe.py
See MaTiSSe.py in action with the [getting started presentation](http://szaghi.github.io/MaTiSSe/#/slide-1) or see the following screenshots.

##### The Titlepage
![shot01](screenshots/01.png)

##### Figure environment
![shot02](screenshots/02.png)

##### LaTeX Equations support
![shot03](screenshots/03.png)

##### LaTeX-Beamer Themes support
![shot04](screenshots/04.png)

Go to [Top](#top)

## Team Members
* Stefano Zaghi, aka _szaghi_ <https://github.com/szaghi>

### Contributors
* not yet... be the first!

Go to [Top](#top)

## <a name="versions"></a>Versions History
In the following the changelog of most important releases is reported.
### v0.0.2
##### Download [ZIP](https://github.com/szaghi/MaTiSSe/archive/v0.0.2.zip) ball or [TAR](https://github.com/szaghi/MaTiSSe/archive/v0.0.2.tar.gz) one
STABLE release. Fully backward compatible. Add PyPI installation support.
### v0.0.1
##### Download [ZIP](https://github.com/szaghi/MaTiSSe/archive/v0.0.1.zip) ball or [TAR](https://github.com/szaghi/MaTiSSe/archive/v0.0.1.tar.gz) one
First, STABLE release.

Go to [Top](#top)
